@@ -19,7 +19,11 @@ class PromotionRuleInline(admin.StackedInline):
     ]
     formfield_overrides = {
         models.JSONField: {"widget": JSONEditorWidget},
-        models.ManyToManyField: {"widget": autocomplete.ModelSelect2Multiple()},
+    }
+    widgets = {
+        "products": autocomplete.ModelSelect2Multiple(
+            url="product-autocomplete",
+        )
     }
 
 
@@ -96,9 +100,9 @@ class CouponAdmin(admin.ModelAdmin):
             },
         ),
     )
-    inlines = [
-        PromotionRuleInline,
-    ]
+    # inlines = [
+    #     PromotionRuleInline,
+    # ]
 
 
 @admin.register(PromotionRule)
