@@ -87,7 +87,7 @@ class Coupon(PromotionBaseModel):
 
 
 class PromotionRule(PromotionBaseModel):
-    coupon = models.ForeignKey(
+    coupon = models.OneToOneField(
         Coupon,
         verbose_name=_("coupon"),
         help_text=_("Coupon."),
